#[non_exhaustive]pub struct NPrintRow {
pub bits: Vec<NPrintBit>,
}Available on crate feature
ml-features-nprint only.Expand description
One nPrint row — ternary per-bit encoding of one packet’s headers.
Width is fixed by the parent matrix’s super::NPrintConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bits: Vec<NPrintBit>Ternary bits, MSB-first within each byte of each header region (Eth → IPv4 → TCP → UDP, in that order, when enabled by the config).
Implementations