Module event

Module event 

Available on crate feature tracker only.
Events emitted by crate::FlowTracker as packets flow through it.

Structs

FlowStats
Aggregate counters maintained per flow.

Enums

EndReason
Why a flow ended.
FlowEvent
Events emitted by the tracker.
FlowSide
Which side of a flow a packet belongs to.
FlowState
Lifecycle state of a flow as tracked by crate::FlowTracker.